/*
 * HealthcardIO - a library providing functionality for accessing healthcards
 *
 * Copyright (C) 2017  gematik - Gesellschaft für Telematikanwendungen der Gesundheitskarte mbH
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

package de.gematik.security.crypto;

import java.security.AccessController;
import java.security.PrivilegedAction;
import java.security.Provider;

/**
 * Security provider that provides JCA/JCE standard access to functionality of class CardBasedSignature.
 *
 * @author André Szdzuy
 */
public class HealthcardSignatureProvider extends Provider {

    public HealthcardSignatureProvider() {
        super("HealthcardSignatureProvider", 1.0, "Healthcard Signature Provider");
        AccessController.doPrivileged(new PrivilegedAction<Void>() {
            public Void run() {
                put("Signature.SHA256withRSA", CardBasedSignature.SHA256withRSA.class.getName());
                put("Signature.SHA256withRSAandMGF1", CardBasedSignature.SHA256withRSAandMGF1.class.getName());
                put("Signature.SHA256withIso9796d2PSS", CardBasedSignature.SHA256withIso9796d2PSS.class.getName());
                return null;
            }
        });
    }

}
